@@ -747,7 +747,7 @@ class ImageTransitionChromaKeyBlue : public ImageTransition
 	public:
 		char *GetDescription( ) const
   		{
-    		return "Chroma Key"; 
+    		return "Chroma key on blue"; 
   		}
 
   		void GetFrame( uint8_t *io, uint8_t *mesh, int width, int height, double position, double frame_delta, bool reverse )
@@ -2351,10 +2351,9 @@ class RWPipe
 		int reader;
 		int writer;
 		GError *error;
-		string m_command;
 
 	public:
-		RWPipe( ) : pid( -1 ), error( NULL ), m_command( "" )
+		RWPipe( ) : pid( -1 ), error( NULL )
 		{
 		}
 
@@ -2371,8 +2370,6 @@ class RWPipe
 			fuckwits[ 2 ] = ( char * )command.c_str( );
 			fuckwits[ 3 ] = NULL;
 
-			m_command = command;
-
 			return g_spawn_async_with_pipes( ".", fuckwits, NULL, G_SPAWN_LEAVE_DESCRIPTORS_OPEN, NULL, NULL, &pid, &writer, &reader, NULL, &error );
 		}
 	
@@ -2440,11 +2437,6 @@ class RWPipe
 				pid = -1;
 			}
 		}
-
-		string GetCurrentCommand( )
-		{
-			return m_command;
-		}
 };
 
 class EffectTV : public GDKImageFilter
@@ -2530,14 +2522,11 @@ class EffectTV : public GDKImageFilter
 		}
 };
 
-class PipeFilter : public GDKImageFilter, public GtkKinoContainer, private KeyFrameControllerClient, 
-	      private PreviewAreaClient, public SelectionNotification
+class PipeFilter : public GDKImageFilter
 {
 	private:
 		GtkWidget *window;
-		KeyFrameController *controller;
-		PreviewArea *area;
- 		RWPipe filter;
+		RWPipe filter;
 
 	public:
 		PipeFilter( )
@@ -2569,90 +2558,23 @@ class PipeFilter : public GDKImageFilter, public GtkKinoContainer, private KeyFr
 		
 		void AttachWidgets( GtkBin *bin ) 
 		{
-			// Create controller
-			controller = CreateWidgetKeyFrameController(this);
-			AttachGtkWidget("frame_key_frame_control", controller);
-     
-			// Create preview area
-			area = CreateWidgetPreviewArea(this);
-			AttachGtkWidget("frame_preview", area);
- 			gtk_widget_reparent( ( GTK_BIN( window ) )->child, GTK_WIDGET( bin ) );
+			gtk_widget_reparent( ( GTK_BIN( window ) )->child, GTK_WIDGET( bin ) );
 		}
-  
+
 		void DetachWidgets( GtkBin *bin ) 
 		{ 
 			gtk_widget_reparent( ( GTK_BIN( bin ) )->child, GTK_WIDGET( window ) );
-			DetachGtkWidget("frame_key_frame_control", controller);
-			delete controller;
-			DetachGtkWidget("frame_preview", area);
-			delete area;
 			filter.Close( );
 		}
 
 		void InterpretWidgets( GtkBin *bin ) 
 		{
-			RefreshCommand( true );
-		}
-
-		void RefreshCommand( bool restart = false )
-		{
+			filter.Close( );
 			GtkCombo *combo = GTK_COMBO( my_lookup_widget( window, "combo1" ) );
 			GtkEntry *entry = GTK_ENTRY( combo->entry );
 			char temp[ 1024 ];
 			sprintf( temp, "exec %s", gtk_entry_get_text( entry ) );
-
-			if ( restart || string( temp ) != filter.GetCurrentCommand( ) )
-			{
-				filter.Close( );
-				filter.Open( temp );
-			}
-		}
-
-		void Refresh(double position)
-		{     
-			/* Create controller */
-			RefreshCommand( );
-			controller->ShowCurrentStatus(position, LOCKED_KEY, false, false);
-     
-			/* Set size of the preview window */
-			int preview_width = 360;
-			int preview_height = 288;
-			uint8_t *preview = new uint8_t[preview_width * preview_height *3];
-			SelectedFrames &selected = GetSelectedFramesForFX();
-     
-			if(selected.GetNumInputFrames() > 0)
-				selected.GetImageA(controller->GetCurrentPosition(), preview, preview_width, preview_height);
-			else
-				memset(preview, 255, preview_width * preview_height * 3);       
-     
-			FilterFrame(preview, preview_width, preview_height, controller->GetCurrentPosition(), 0.01);
-			area->ShowImage(50, 50, preview, preview_width, preview_height);
-			delete preview;       
-		}
- 
-		void Refresh()
-		{
-			Refresh(controller->GetCurrentPosition());
-		}
-   
-		void OnControllerPositionChanged(double position)
-		{
-			Refresh(position);
-		}
-   
-		void OnPreviewAreaRefresh(PreviewArea *area)
-		{
-			Refresh();
-		}
-   
-		void OnSelectionChange()
-		{
-			Refresh();
-		}
-
-		GtkWidget *GetGtkWidget()
-		{
-			return window;
+			filter.Open( temp );
 		}
 };
 
@@ -3017,7 +2939,7 @@ class FfmpegDub : public GDKAudioFilter
 			gtk_widget_reparent( ( GTK_BIN( bin ) )->child, GTK_WIDGET( window ) );
 		}
 
-		void GetFrame( int16_t **buffer, int frequency, int channels, int samples, double position, double frame_delta )
+		void GetFrame( int16_t **buffer, int frequency, int channels, int &samples, double position, double frame_delta )
 		{
 			if ( !m_pipe.IsRunning( ) )
 			{
