@@ -83,7 +83,7 @@ class KinoPlusKeyFrameController : public KeyFrameController
 		KinoPlusKeyFrameController( KeyFrameControllerClient *in_client ) : gui_locked( false ), client( in_client )
 		{
 			window = create_kino_key_frame_control( );
-			GtkWidget *widget = my_lookup_widget( window, "togglebutton" );
+			GtkWidget *widget = my_lookup_widget( window, "togglebutton_key_frame" );
 			gtk_signal_connect( GTK_OBJECT( widget ), "toggled", GTK_SIGNAL_FUNC( on_control_key_frame ), this ); 
 			widget = my_lookup_widget( window, "button_prev" );
 			gtk_signal_connect( GTK_OBJECT( widget ), "toggled", GTK_SIGNAL_FUNC( on_control_prev_key_clicked ), this ); 
@@ -118,7 +118,7 @@ class KinoPlusKeyFrameController : public KeyFrameController
 			SetCurrentPosition( position );
 
 			// Determine Key button status
-			GtkWidget *widget = my_lookup_widget( window, "togglebutton" );
+			GtkWidget *widget = my_lookup_widget( window, "togglebutton_key_frame" );
 
 			if ( type & LOCKED_KEY )	 // Locked Key
 			{
@@ -167,7 +167,7 @@ class KinoPlusKeyFrameController : public KeyFrameController
 		{
 			if ( ! gui_locked )
 			{
-				GtkWidget *widget = my_lookup_widget( window, "togglebutton" );
+				GtkWidget *widget = my_lookup_widget( window, "togglebutton_key_frame" );
 				client->OnControllerKeyChanged( GetCurrentPosition( ), gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON( widget ) ) );
 			}
 		}
